%% This main file is used to execute the simulation functions for the nonlinear vibrations of thin plates. 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%Premier tour : les parametres tels qu'ils sont
%% Input parameters files
PlateCharacteristicsFileName = 'PlateCharacteristicsCircularCT4.mat'; % Physical characteristics of the plate: Dimensions, imperfection profile, material and boundary conditions.  
SimulationParametersFileName = 'SimulationParametersCircularCT4.mat'; % Parameters related to the simulation: Time length, scheme, number of modes, output points, accuracy.
GammaFileName = 'GammaCircular-Nphi_NPHICircular.mat'; % Name of the file containing the Gamma Tensor.  
ScoreFileName = 'ScoreParametersCircularCT4.mat'; % Characteristics of the excitation. 
OutputFileName = 'ResultsCircularCT4'; % Name of the results files and folder. 



%% Simulation setup 
simulation = 1;

[Rd, hd, E, BC, e, Nphi, Npsi, scheme, H0, H1, H2, filename, Ai, C, C1, C2, k_t, c_t, xkn, JJ, II, Kkn, rp, tad, fs, Tsd] = plate_def_circ(PlateCharacteristicsFileName, SimulationParametersFileName, OutputFileName, GammaFileName );

[ f_time, Tn ] = score_circ(ScoreFileName, Rd, hd, E, BC, e, Nphi, scheme, C, k_t, c_t, xkn, JJ, II, Kkn, tad, fs, Tsd);


%% Time simulation
switch scheme
    case 'ECS'
        [ out_nd ] = ftime_imperfect_ECS( Nphi, Npsi, Ai, H0, H1, H2, C, C1,C2, Tn, e, f_time, rp);
        
    case 'verlet'
        [ out_nd ] = ftime_imperfect_verlet( Nphi, Npsi, Ai, H1, C, C1, C2, Tn, e, f_time, rp);
    
    otherwise
        disp('Unknown scheme');
end

% Save results
fsd = round(fs/tad); % Dimensioned sampling frequency
out = out_nd*hd; % Dimensioned output displacement
out_vel = diff(out,1,1)*fsd; % Dimensioned output velocity
save(sprintf('%s_sim%d.mat',filename,simulation), 'out', 'out_vel',  'fsd');

%% Generate audio from output (Comment this block if the code is not used for sound synthesis purposes)
% for i = 1:size(rp,1)
%     audiowrite(sprintf('%s-Op_%d.wav',filename, i),out_vel(:,i)/1.1/max(abs(out_vel(:,i))),fsd);
% end
audiowrite(out_vel/1.2/max(abs(out_vel)),fsd,'transi120Hz.wav');






%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%3e        tour %%%%%%%%%%%
%%avec une imperfection %%
%% frequence 1           %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%

load PlateCharacteristicsCircularCT4
H=5e-3;
save PlateCharacteristicsCircularCT4 H -append

load ScoreParametersCircularCT4
score_cell{1,2}={0 [130 130 130] [0 20 20] 0 [0 9 12] pi 0.9};
save ScoreParametersCircularCT4 score_cell -append

%% Simulation setup 
[Rd, hd, E, BC, e, Nphi, Npsi, scheme, H0, H1, H2, filename, Ai, C, C1, C2, k_t, c_t, xkn, JJ, II, Kkn, rp, tad, fs, Tsd] = plate_def_circ(PlateCharacteristicsFileName, SimulationParametersFileName, OutputFileName, GammaFileName );

[ f_time, Tn ] = score_circ(ScoreFileName, Rd, hd, E, BC, e, Nphi, scheme, C, k_t, c_t, xkn, JJ, II, Kkn, tad, fs, Tsd);


%% Time simulation
simulation = 3;

switch scheme
    case 'ECS'
        [ out_nd ] = ftime_imperfect_ECS( Nphi, Npsi, Ai, H0, H1, H2, C, C1,C2, Tn, e, f_time, rp);
        
    case 'verlet'
        [ out_nd ] = ftime_imperfect_verlet( Nphi, Npsi, Ai, H1, C, C1, C2, Tn, e, f_time, rp);
    
    otherwise
        disp('Unknown scheme');
end

% Save results
fsd = round(fs/tad); % Dimensioned sampling frequency
out = out_nd*hd; % Dimensioned output displacement
out_vel = diff(out,1,1)*fsd; % Dimensioned output velocity
save(sprintf('%s_sim%d.mat',filename,simulation), 'out', 'out_vel',  'fsd');

%% Generate audio from output (Comment this block if the code is not used for sound synthesis purposes)
% for i = 1:size(rp,1)
%     audiowrite(sprintf('%s-Op_%d.wav',filename, i),out_vel(:,i)/1.1/max(abs(out_vel(:,i))),fsd);
% end
audiowrite(out_vel/1.2/max(abs(out_vel)),fsd,'transi130Hzimperf5mm.wav');


%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%4e        tour %%%%%%%%%%%
%%avec une imperfection %%
%% frequence 2           %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%

load PlateCharacteristicsCircularCT4
H=5e-3;
save PlateCharacteristicsCircularCT4 H -append

load ScoreParametersCircularCT4
score_cell{1,2}={0 [250 250 250] [0 20 20] 0 [0 9 12] pi 0.9};
save ScoreParametersCircularCT4 score_cell -append

%% Simulation setup 
[Rd, hd, E, BC, e, Nphi, Npsi, scheme, H0, H1, H2, filename, Ai, C, C1, C2, k_t, c_t, xkn, JJ, II, Kkn, rp, tad, fs, Tsd] = plate_def_circ(PlateCharacteristicsFileName, SimulationParametersFileName, OutputFileName, GammaFileName );

[ f_time, Tn ] = score_circ(ScoreFileName, Rd, hd, E, BC, e, Nphi, scheme, C, k_t, c_t, xkn, JJ, II, Kkn, tad, fs, Tsd);


%% Time simulation
simulation = 4;

switch scheme
    case 'ECS'
        [ out_nd ] = ftime_imperfect_ECS( Nphi, Npsi, Ai, H0, H1, H2, C, C1,C2, Tn, e, f_time, rp);
        
    case 'verlet'
        [ out_nd ] = ftime_imperfect_verlet( Nphi, Npsi, Ai, H1, C, C1, C2, Tn, e, f_time, rp);
    
    otherwise
        disp('Unknown scheme');
end

% Save results
fsd = round(fs/tad); % Dimensioned sampling frequency
out = out_nd*hd; % Dimensioned output displacement
out_vel = diff(out,1,1)*fsd; % Dimensioned output velocity
save(sprintf('%s_sim%d.mat',filename,simulation), 'out', 'out_vel',  'fsd');

%% Generate audio from output (Comment this block if the code is not used for sound synthesis purposes)
% for i = 1:size(rp,1)
%     audiowrite(sprintf('%s-Op_%d.wav',filename, i),out_vel(:,i)/1.1/max(abs(out_vel(:,i))),fsd);
% end
audiowrite(out_vel/1.2/max(abs(out_vel)),fsd,'transi250Hzimperf5mm.wav');







